Determines if compiled code should be used or not.
Usage
.DSEflags(new)
.DSEflags()
Arguments
new
A list which must have elements COMPILED and DUP.
Side Effects
Setting flags with this function is primarily for debugging. It should not
normally be needed by users.
Several dse functions which call compiled fortran or C code will use
the equivalent S/R version if the .DSEflags()$COMPILED returns
FALSE. .DSEflags()$DUP is passed to
fortran calls and controls whether R duplicates arguments passed
to the fortran code. The safe setting is TRUE. Setting FALSE
saves some memory but does not seem to give much speed gain.